'use strict';

exports.__esModule = true;
exports.bindEvents = bindEvents;
exports.unbindEvents = unbindEvents;

var _underscore = require('underscore');

var _underscore2 = _interopRequireDefault(_underscore);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function bindFromStrings(target, entity, evt, methods, actionName) {
  var methodNames = methods.split(/\s+/);

  _underscore2.default.each(methodNames, function (methodName) {
    var method = target[methodName];
    if (!method) {
      throw new Error('Method "' + methodName + '" was configured as an event handler, but does not exist.');
    }

    target[actionName](entity, evt, method);
  });
}

// generic looping function
function iterateEvents(target, entity, bindings, actionName) {
  // type-check bindings
  if (!_underscore2.default.isObject(bindings)) {
    throw new Error('Bindings must be an object.');
  }

  // iterate the bindings and bind/unbind them
  _underscore2.default.each(bindings, function (method, evt) {

    // allow for a list of method names as a string
    if (_underscore2.default.isString(method)) {
      bindFromStrings(target, entity, evt, method, actionName);
      return;
    }

    target[actionName](entity, evt, method);
  });
}

function bindEvents(entity, bindings) {
  if (!entity || !bindings) {
    return this;
  }

  iterateEvents(this, entity, bindings, 'listenTo');
  return this;
}

function unbindEvents(entity, bindings) {
  if (!entity) {
    return this;
  }

  if (!bindings) {
    this.stopListening(entity);
    return this;
  }

  iterateEvents(this, entity, bindings, 'stopListening');
  return this;
}